@@ -11,7 +11,7 @@ from enum import Enum
 List  = typing.List
 Tuple = typing.Tuple
 pypi_base_url = "http://zifuture.com:1556/fs/pypi"
-version = "1.1.21"
+version = "1.1.25"
 
 lean_metas = [
     {
@@ -21,8 +21,8 @@ lean_metas = [
         "tensorRT": "8.0.1.6",
         "min_driver_version_linux": "440.33",
         "min_driver_version_windows": "441.22",
-        "binary_url_linux": f"{pypi_base_url}/nvbin/v3.0/trt8cuda102cudnn8.zip",
-        "binary_linux_md5": "6ac2d4b8ed14a483bb88629e5ee4c1c5",
+        "binary_url_linux": f"{pypi_base_url}/nvbin/v5.0/trt8cuda102cudnn8.zip",
+        "binary_linux_md5": "67fddf1f9d54f7b58a1db27a7724d792",
         "syslib_linux_md5": "08f8c76348d3a0a7a076f9f6f5a928a3",
         "syslib_windows_md5": None,
         "binary_url_windows": None,
@@ -55,8 +55,8 @@ lean_metas = [
         "tensorRT": "8.0.3.4",
         "min_driver_version_linux": "460.27.04",
         "min_driver_version_windows": "460.89",
-        "binary_url_linux": f"{pypi_base_url}/nvbin/v3.0/trt8cuda112cudnn8.zip",
-        "binary_linux_md5": "9ac5b183a05ae494d16ae8e7e1ade5d8",
+        "binary_url_linux": f"{pypi_base_url}/nvbin/v5.0/trt8cuda112cudnn8.zip",
+        "binary_linux_md5": "94abf8c8851ececf8d8eb5b6ff281299",
         "syslib_linux_md5": "08f8c76348d3a0a7a076f9f6f5a928a3",
         "syslib_windows_md5": None,
         "binary_url_windows": None,
@@ -636,7 +636,9 @@ def __load_symbols(pyc_meta, load_lean_library=True):
             if name.startswith("libcudnn.so"): return 8
             if name.startswith("libnvinfer.so"): return 9
             if name.startswith("libnvinfer_plugin.so"): return 10
-            return 11
+            if name.startswith("libprotobuf.so"): return 11
+            if name.startswith("libprotoc.so"): return 12
+            return 13
 
         cuda_libs = os.listdir(nvlib64_root)
         cuda_libs = sorted(cuda_libs, key=sorted_libs)
