@@ -83,9 +83,11 @@ def download_and_verify_md5_saveto_file(url, file):
     
     return True, remote_md5
 
-def extract_zip_to(file, to):
+def extract_zip_to(file, to, print_info=True):
     zfile = zipfile.ZipFile(file)
     zfile.extractall(to)
-    for file in zfile.namelist():
-        print(f"Extract to {os.path.join(to, file)}")
+
+    if print_info:
+        for file in zfile.namelist():
+            print(f"Extract to {os.path.join(to, file)}")
     return zfile.namelist()
\ No newline at end of file
